# Datensparsamkeit
Even though the basic idea of puddl is to run crazy analytics on your personal
data (after you collected lots of it), we don't want to index/analyze all data.
Datensparsamkeit is a general concept that emphasizes minimalism when collecting
data.

## Push Data
We make use of our own laziness to enforce Datensparsamkeit.  In order to get
data into puddl, you have to explicitly push it: either by writing to it
directly or by loading/indexing some existing data into puddl.
